@@ -3,7 +3,7 @@ use warnings;
 
 package Dist::Zilla::App::Command::xtest;
 # ABSTRACT: run xt tests for your dist
-our $VERSION = '0.019'; # VERSION
+our $VERSION = '0.020'; # VERSION
 use Dist::Zilla::App -command;
 
 use Moose::Autobox;
@@ -129,7 +129,7 @@ sub execute {
             );
             my @t = map { "$_" } $pcr->all('xt');
             if (@t) {
-                $app->process_args( '-j', $self->jobs, qw/-r -b/, @t ) if @t;
+                $app->process_args( '-j', $opt->jobs, qw/-r -b/, @t ) if @t;
                 $error = "Failed xt tests" unless $app->run;
             }
             else {
@@ -137,7 +137,7 @@ sub execute {
             }
         }
         else {
-            $app->process_args( '-j', $self->jobs, qw/-r -b xt/ );
+            $app->process_args( '-j', $opt->jobs, qw/-r -b xt/ );
             $error = "Failed xt tests" unless $app->run;
         }
     }
@@ -169,7 +169,7 @@ Dist::Zilla::App::Command::xtest - run xt tests for your dist
 
 =head1 VERSION
 
-version 0.019
+version 0.020
 
 =head1 SYNOPSIS
 
